/*******************************************************************************
* Copyright (c) 2007, Perforce Software, Inc.  All rights reserved.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
* 
* 1.  Redistributions of source code must retain the above copyright
*     notice, this list of conditions and the following disclaimer.
* 
* 2.  Redistributions in binary form must reproduce the above copyright
*     notice, this list of conditions and the following disclaimer in the
*     documentation and/or other materials provided with the distribution.
* 
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
* "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
* LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
* FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL PERFORCE 
* SOFTWARE, INC. BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
* LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
* DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON 
* ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR 
* TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
* THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH 
* DAMAGE.
*******************************************************************************/

//------------------------------------------------------------------------------
//    Support structures for parser
//------------------------------------------------------------------------------
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "parsesupp.h"
#include "vararray.h"
#define MAX_ERRORS	20

static VarArray *file_stack = 0;

extern "C" {

void
yyerror( const char *s )
{
    fprintf( stderr, "%s on line %d of configuration file %s.\n", s, lineno, fname ? fname : "" );
    fprintf( stderr, "Aborting...\n" );
    exit( 1 );
}


int 
yywrap()
{
	return 1;
}

void
parser_push( parser_ctx *pc )
{
    if( !file_stack ) file_stack = new VarArray;
    file_stack->Put( (void *)pc );

}

parser_ctx *
parser_pop()
{
    parser_ctx *pc;

    if( !file_stack ) return 0;
    if( !file_stack->Count() ) return 0;
    pc = (parser_ctx *)file_stack->Get( file_stack->Count() - 1);
    file_stack->Remove( file_stack->Count() - 1 );
    return pc;
}

} /* Extern C */
